function Bl = LamBasis(theta,phi,lambda,Ll,re)

% function Bl = LamBasis(theta,phi,Ll)
%
% calculates the Lambertian basis images of an object, specified by the surface
% normals theta, phi and albedo lambda. The first Ll harmonic images are
% calculated
%
% Sameer Shirdhonkar (7 April 2005)
% Modified: 20 Dec 2006				

if(nargin==4)
  re = 1;	% real or complex basis
end

k = calcklp(Ll,1);		% Lambertican attenuation
b = SHY(0:Ll,theta,phi);
b = b .* repmat(shiftdim(lambda,-2),[size(b,1) size(b,2) 1 1]);
Bl = zeros(size(b,3)*size(b,4),(Ll+1)^2);
for l=0:Ll
  if(re==1)	% real
    m = 0;
    Bl(:,1+l*(l+1)+m) = sqrt(4*pi/(2*l+1)) * k(l+1) * reshape(b(l+1,m+1,:,:)...
    ,[],1);
    for m=1:l
      Bl(:,1+l*(l+1)+m) = sqrt(4*pi/(2*l+1)) * k(l+1) * sqrt(2) * real( ...
      reshape(b(l+1,m+1,:,:), [],1) );
      Bl(:,1+l*(l+1)-m) = sqrt(4*pi/(2*l+1)) * k(l+1) * sqrt(2) * imag( ...
      reshape(b(l+1,m+1,:,:), [],1) );
    end
  else
    for m=0:l
      Bl(:,1+l*(l+1)+m) = sqrt(4*pi/(2*l+1))*k(l+1)*reshape(b(l+1,m+1,:,:),[],1);
      Bl(:,1+l*(l+1)-m) = (-1)^m*conj(Bl(:,1+l*(l+1)+m));
    end
  end
end
