function Bp = PhongBasis(theta,phi,lambda,p,Lp,re)

% function Bp = PhongBasis(theta,phi,lambda,p,Lp)
%
% Caclulates the Phong basis images of an object, specified by the surface
% normals (theta,phi), the albedo lambda, and the Phong power p. The first Lp
% harmonic images are calculated (for all m)
%
% Sameer Shirdhonkar (7 April 2005)
% Modified: 20 Dec 2006, 31 March 2008				


if(nargin==4)
  re = 1;	% real or complex basis
end

k = calcklp(Lp,p);		% Lambertican attenuation
b = SHY(0:Lp,2*theta,phi);
b = b .* repmat(shiftdim(lambda,-2),[size(b,1) size(b,2) 1 1]);
Bp = zeros(numel(b(1,1,:,:)), (Lp+1).^2);
for l=0:Lp
  if(re==1)	% real
    m = 0;
    Bp(:,1+l*(l+1)+m) = sqrt(4*pi/(2*l+1)) * k(l+1) * reshape(b(l+1,m+1,:,:),...
    [numel(b(l+1,m+1,:,:)),1]);
    for m=1:l
      Bp(:,1+l*(l+1)+m) = sqrt(4*pi/(2*l+1)) * k(l+1) * sqrt(2) * real( ...
      reshape(b(l+1,m+1,:,:), [numel(b(l+1,m+1,:,:)),1]) );
      Bp(:,1+l*(l+1)-m) = sqrt(4*pi/(2*l+1)) * k(l+1) * sqrt(2) * imag( ...
      reshape(b(l+1,m+1,:,:), [numel(b(l+1,m+1,:,:)),1]) );
    end
  else
    for m=0:l
      Bp(:,1+l*(l+1)+m) = sqrt(4*pi/(2*l+1))*k(l+1)*reshape(b(l+1,m+1,:,:),...
      [numel(b(l+1,m+1,:,:)),1]);
      Bp(:,1+l*(l+1)-m) = (-1)^m*conj(Bp(:,1+l*(l+1)+m));
    end
  end
end
