% Model Based Specular Object Recognition: Enforcing the Non-negativity of light 
% constraint using Semi-definite Programming.
% Sameer Shirdhonkar (20 Dec 2006)
% ______________________________________________________________________________
% 
% Please install these Matlab toolboxes first:
% 
% SDPT3 (http://www.math.nus.edu.sg/~mattohkc/sdpt3.html)
% Yalmip (http://control.ee.ethz.ch/~joloef/yalmip.php)
% 
% This Matlab package consists of:
% 
% readme.txt      : Instructions
% gensdp.m        : The main program - Given an object model (surface normals, 
%                 albedo and reflectance type), computes Lighting and image 
%                 error.
%                 NOTE: This will run slowly the first time, since it computes 
%                 the coefficient matrix. From the next run onwards, it will be 
%                 faster, as long as L is kept constant.
% 
% Basis.m         : These 3 files compute basis images of an object from its
% LamBasis.m      : model, for mirror, Lambertian and Phong reflection models
% PhongBasis.m    : respectively.
% 
% SHY.m           : Compute Spherical Harmonic function values
% calcklp.m       : Calculate spherical harmonic coefficients of the function 
%                      f(x) = x^p (if x>0), else f(x) = 0.
% realGaunt.m     : Compute coupling coefficients for real spherical harmonics, 
%                   using coupling coefficients for complex SH.
% Gaunt.nb        : Mathematica notebook for calculating Gaunt coefficients.
% Gaunt.mat       : Datafile storing Complex SH coupling coefficients up to 
%                   order L = 10.
% C.mat           : Datafile storing coefficient matrix for a particular value 
%                   of L
% 
% These are some support functions for testing
% render.m        : Create image of an object given its normals, albedo, 
%                 lighting model and spherical harmonic lighting.
% showsf.m        : Display functions defined on a sphere.
% 
% Each Matlab file has instructions for its use.
