function f = realGaunt(l1,l2,l3,m1,m2,m3)

% function f = realGaunt(l1,l2,l3,m1,m2,m3)
%
% Calculates the coupling coefficients of the real Spherical Harmonics defined
% as :
%          sqrt(2) * Re(Y_lm)  	[m>0] 
% X_lm =   Y_lm			[m=0]
%	   sqrt(2) * Im(Y_lm)	[m<0]
% The coupling coefficients, also called real Gaunt coefficients are defined as:
% <l3m3|l1m1|l2m2>_R = Int { X_l1m1 X_l2m2 X_l3m3 }
% Properties: invariant to shuffling of 1,2,3
%
% Sameer Shirdhonkar (7 April 2005)
% Modified: 20 Dec 2006				

if(abs(m3)~=abs(m1+m2) && abs(m3)~=abs(m1-m2))
  f = 0;
  return;
end

c = sortrows([m1 l1; m2 l2; m3 l3],1);
l1 = c(1,2); l2 = c(2,2); l3 = c(3,2); m1 = c(1,1); m2 = c(2,1); m3 = c(3,1);

global Gaunt;
if(isempty(Gaunt))
  load('Gaunt.mat');
end

if(m1==0 && m2==0)
  f = Gaunt{l1+1,l2+1,l3+1,l1+m1+1,l2+m2+1};
  return;
else
  if(m1==0)
    f = 2*real(conj(ulm1m2(l1,m3,m2))*ulm1m2(l2,m2,m2))*...
    Gaunt{l1+1,l2+1,l3+1,l1+m1+1,l2+m2+1};
  else
    if(abs(m3)==abs(m1+m2))
      f = 2*real(conj(ulm1m2(l1,m3,m1+m2))*ulm1m2(l1,m1,m1)*ulm1m2(l2,m2,m2))*...
    Gaunt{l1+1,l2+1,l3+1,l1+m1+1,l2+m2+1};
    else %abs(m3)==abs(m1-m2)
      f = 2*real(conj(ulm1m2(l1,m3,m2-m1))*ulm1m2(l1,m1,-m1)*ulm1m2(l2,m2,m2))*...
    Gaunt{l1+1,l2+1,l3+1,l1-m1+1,l2+m2+1};
    end
  end
end
%else
%  f = (ulm1m2(l1,m1,m1)*ulm1m2(l2,m2,m2)*conj(ulm1m2(l3,m1+m2,m1+m2)) + ...
%  ulm1m2(l1,m1,-m1)*ulm1m2(l2,m2,-m2)*conj(ulm1m2(l3,m1+m2,-m1-m2)))...
%  *sqrt((2*l1+1)*(2*l2+1)/(4*pi*(2*l3+1)))*CG(l1,l2,l3,m1,m2,m3)*CG(l1,l2,l3,0,0,0);

%+ulm1m2(l1,m1,m1)*ulm1m2(l2,m2,-m2)*conj(ulm1m2(l3,m1+m2,m1-m2))*CG(l1,l2,l3,m1,-m2)
%+ulm1m2(l1,m1,-m1)*ulm1m2(l2,m2,m2)*conj(ulm1m2(l3,m1+m2,-m1+m2))*CG(l1,l2,l3,-m1,m2)

return;


%----------------------------------------
function f = ulm1m2(l,m1,m2)

% Unitary transformation from complex to spherical harmonics

if(abs(m1)~=abs(m2))
  f = 0;
  return;
end

if(m1==0 && m2==0)
  f = 1;
  return;
end

if(m1>0 && m2>0)
  f = sqrt(1/2);
  return;
end

if(m1<0 && m2>0)
  f = -j/sqrt(2);
  return;
end

if(m1>0 && m2<0)
  f = (-1)^m2/sqrt(2);
  return;
end

f = (-1)^m1*j/sqrt(2);	% m1<0 && m2<0
return;
