function showsf(fun,mode,n)

% function showsf(fun,mode,n)
%
% plot function fun (function handle or inline) on the sphere
% mode = 0 => plot magnitude (default)
% mode = 1 => plot real and imaginary parts
% mode = 2 => plot real part
% mode = 3 => plot imaginary part
% mode = 4 => show image on surface of sphere (fun should be real)
% n denotes number of node points (default = 50)
%
% Sameer Shirdhonkar (7 April 2005)
% Modified: 20 Dec 2006				

if nargin<2
    mode = 0;
end
if nargin<3
    n=50;
end

theta = 0:pi/n:pi;
phi = 0:pi/n:2*pi;

if isnumeric(fun) || islogical(fun)
  if(length(fun)==(n+1)*(2*n+1))
    f = reshape(fun,n+1,2*n+1);
  else
    if(all(size(fun)==[n+1,2*n+1]))
      f = fun;
    else
      error('size(fun) should be [%d,%d]\n',n+1,2*n+1);
    end
  end
else
  if isa(fun,'inline')
    if char(argnames(fun)) ~= char({'theta','phi'})
	error('The arguments of fun should be theta and phi');
    end  
  else
    if ischar(fun)
	fun = inline(fun,'theta','phi');
    end
  end
  f = reshape(feval(fun,theta,phi),n+1,2*n+1) ;
end

x = sin(theta)'*cos(phi);
y = sin(theta)'*sin(phi);
z = cos(theta)'*ones(size(phi));

%figure;

switch mode
  case 0,		% Plot only magnitude
    surf(abs(f).*x, abs(f).*y, abs(f).*z,abs(f));
  case 1,		% plot real and imaginar parts
    subplot(1,2,1);
    surf(real(f).*x,real(f).*y,real(f).*z,real(f));
    subplot(1,2,2);
    surf(imag(f).*x,imag(f).*y,imag(f).*z,imag(f));
  case 2,		% Plot real part
    surf(real(f).*x,real(f).*y,real(f).*z,real(f));
  case 3,		% plot imaginary part
    surf(imag(f).*x,imag(f).*y,imag(f).*z,imag(f));
  case 4,		% plot image
    if(imag(f)~=0)
      warning('Image is not real\n');
    end
    surf(x,y,z,real(f));
    colormap gray;
end

set(gcf, 'Renderer','OpenGL'); 
%colorbar;
axis equal vis3d;
shading interp;
cameramenu;
set(gca,'Projection','Orthographic');
xlabel('X'); ylabel('Y'); zlabel('Z');
